<?php
namespace bwdwpvx_ProductVendors_namespace\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class bwdwpvx_ProductVendors_widgets extends Widget_Base {

    public function get_name() {
		return esc_html__( 'bwdwpvx-restaurant-food-menu', 'bwdwpvx-product-vendors' );
	}

	public function get_title() {
		return esc_html__( 'WooCommerce Product Vendors', 'bwdwpvx-product-vendors' );
	}

	public function get_icon() {
		return 'bwdwpvx-ProductVendors-icon';
	}

	public function get_categories() {
		return [ 'bwdwpvx-ProductVendors-category' ];
	}

    protected function register_controls() {

        //Start bwdwpvx List General Section.
        $this->start_controls_section(
            'bwdwpvx_general_section', array(
                'label'             => esc_html__('General', 'bwdwpvx-product-vendors'),
            )
        );

        //Food Menu Type.
        $this->add_control(
            'bwdwpvx_product_source', [
                'label'             => esc_html__('Food Menu Source', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT,
                'options'           => bwdwpvx_menu_type(),
                'default'           => 'custom',
            ]
        );

        //Food Menu Design.
        $this->add_control(
            'bwdwpvx_product_layout', [
                'label'                 => esc_html__('Food Menu Layout', 'bwdwpvx-product-vendors'),
                'type'                  => \Elementor\Controls_Manager::SELECT,
                'options'               => [
                    'bwdwpvx-design-1'   => esc_html__('Design 1', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-2'   => esc_html__('Design 2', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-3'   => esc_html__('Design 3', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-4'   => esc_html__('Design 4', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-5'   => esc_html__('Design 5', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-6'   => esc_html__('Design 6', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-7'   => esc_html__('Design 7', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-8'   => esc_html__('Design 8', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-9'   => esc_html__('Design 9', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-10'  => esc_html__('Design 10', 'bwdwpvx-product-vendors'),
                    'bwdwpvx-design-11'  => esc_html__('Design 11', 'bwdwpvx-product-vendors'),
                ],
                'default'               => 'bwdwpvx-design-1',
            ]
        );

        $this->end_controls_section();
        //End bwdwpvx List General Section.

        //Start Grid Options Section.
        $this->start_controls_section(
            'bwdwpvx_grid_option_section', array(
                'label'             => esc_html__('Grid Options', 'bwdwpvx-product-vendors'),
            )
        );

        //Grid Columns.
        $this->add_responsive_control(
            'bwdwpvx_grid_columns', [
                'label'             => esc_html__('Grid Columns', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT,
                'options'           => [
                    'default'       => 'Default',
                    '1'             => '1',
                    '2'             => '2',
                    '3'             => '3',
                    '4'             => '4',
                    '5'             => '5',
                    '6'             => '6',
                ],  
				'desktop_default'   => 'default',
				'tablet_default'    => 'default',
				'mobile_default'    => 'default',
                'prefix_class'      => 'elementor-grid%s-',
                'frontend_available'=> true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-container' => 'grid-template-columns: repeat({{VALUE}},1fr);',
                ],
            ]
        );

        //Grid Column Gap.
        $this->add_responsive_control(
            'bwdwpvx_product_column_gap', [
                'label'              => esc_html__('Grid Column Gap', 'bwdwpvx-product-vendors'),
                'type'               => \Elementor\Controls_Manager::SLIDER,
                'default'            => [
                    'size'           => 30,
                ],      
                'range'              => [
                    'px'             => [
                        'min'        => 0,
                        'max'        => 100,
                    ],
                ],
                'frontend_available' => true,
                'selectors'          => [
                    '{{WRAPPER}} .bwdwpvx-container' => 'grid-column-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        //Grid Row Gap.
        $this->add_responsive_control(
            'bwdwpvx_product_row_gap', [
                'label'             => esc_html__('Grid Row Gap', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'default'           => [
                    'size'          => 30,
                ],  
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 100,
                    ],
                ],
                'frontend_available' => true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-container' => 'grid-row-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        //Custom Currency Symbol.
        $this->add_control(
            'bwdwpvx_currency_symbol', [
                'label'             => esc_html__('Currency Symbol', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT,
                'options'           => [
                    ''              => esc_html__('None', 'bwdwpvx-product-vendors' ),
                    'dollar'        => '&#36; ' . _x('Dollar', 'Currency', 'bwdwpvx-product-vendors'),
                    'euro'          => '&#128; ' . _x('Euro', 'Currency', 'bwdwpvx-product-vendors'),
                    'baht'          => '&#3647; ' . _x('Baht', 'Currency', 'bwdwpvx-product-vendors'),
                    'franc'         => '&#8355; ' . _x('Franc', 'Currency', 'bwdwpvx-product-vendors'),
                    'guilder'       => '&fnof; ' . _x('Guilder', 'Currency', 'bwdwpvx-product-vendors'),
                    'krona'         => 'kr ' . _x('Krona', 'Currency', 'bwdwpvx-product-vendors'),
                    'lira'          => '&#8356; ' . _x('Lira', 'Currency', 'bwdwpvx-product-vendors'),
                    'peso'          => '&#8369; ' . _x('Peso', 'Currency', 'bwdwpvx-product-vendors'),
                    'pound'         => '&#163; ' . _x('Pound Sterling', 'Currency', 'bwdwpvx-product-vendors'),
                    'real'          => 'R$ ' . _x('Real', 'Currency', 'bwdwpvx-product-vendors'),
                    'ruble'         => '&#8381; ' . _x('Ruble', 'Currency', 'bwdwpvx-product-vendors'),
                    'rupee'         => '&#8360; ' . _x('Rupee', 'Currency', 'bwdwpvx-product-vendors'),
                    'indian_rupee'  => '&#8377; ' . _x('Rupee (Indian)', 'Currency', 'bwdwpvx-product-vendors'),
                    'shekel'        => '&#8362; ' . _x('Shekel', 'Currency', 'bwdwpvx-product-vendors'),
                    'yen'           => '&#165; ' . _x('Yen/Yuan', 'Currency', 'bwdwpvx-product-vendors'),
                    'won'           => '&#8361; ' . _x('Won', 'Currency', 'bwdwpvx-product-vendors'),
                    'bwdwpvx_custom' => esc_html__('Custom', 'bwdwpvx-product-vendors'),
                ],
                'default'           => 'dollar',
                'condition'         => ['bwdwpvx_product_source' => 'custom'],
            ]
        );

        //Custom Currency Text.
        $this->add_control(
            'bwdwpvx_currency_text_symbol', [
                'label'             => esc_html__('Custom Symbol', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::TEXT,
                'condition'         => [
                    'bwdwpvx_currency_symbol' => 'bwdwpvx_custom',
                ],
            ]
        );

        $this->end_controls_section();
        //End Grid Options Section.

        //Start Custom Item Section.
        $this->start_controls_section(
            'bwdwpvx_custom_item_section', array(
                'label'             => esc_html__('Item', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_product_source' => 'custom'],
            )
        );

        //Start Repeater Control.
        $repeater = new \Elementor\Repeater();

        //Custom Title.
        $repeater->add_control(
			'bwdwpvx_title', [
                'label'             => esc_html__('Title', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::TEXT,
                'default'           => esc_html__('Title', 'bwdwpvx-product-vendors'),
				'label_block'       => true,
                'dynamic'           => ['active' => true],
			]
		);

        //Custom Content.
        $repeater->add_control(
			'bwdwpvx_list_content', [
				'label'             => esc_html__('Content', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::TEXTAREA,
                'default'           => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit sed do eiusmod', 'bwdwpvx-product-vendors'),
			]
		);

        //Show Custom Image.
        $repeater->add_control(
            'bwdwpvx_show_custom_image', [
                'label'             => esc_html__('Show Image', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //Custom Image.
        $repeater->add_control(
			'bwdwpvx_image', [
				'label'             => esc_html__('Choose Image', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::MEDIA,
                'dynamic'           => [
					'active'        => true,
				],
				'default'           => [
                    'url'           => bwdwpvx_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/image/food.jpg',
				],
                'condition'         => ['bwdwpvx_show_custom_image' => 'yes'],
			]
		);

        //Show Custom Icon.
        $repeater->add_control(
            'bwdwpvx_show_custom_icon', [
                'label'             => esc_html__('Show Icon', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'no',
            ]
        );

        //Custom Icon.
        $repeater->add_control(
            'bwdwpvx_icon', [
                'label'             => esc_html__('Icon', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::ICONS,
                'default'           => [
                    'value'         => 'fas fa-leaf',
                    'library'       => 'fa-solid',
                ],
                'condition'         => [
                    'bwdwpvx_show_custom_icon' => 'yes',
                ],
            ]
        );

        //Show Label.
        $repeater->add_control(
            'bwdwpvx_show_label', [
                'label'             => esc_html__('Show Label', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //Custom Label Text.
        $repeater->add_control(
			'bwdwpvx_label', [
				'label'             => esc_html__('Label', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::TEXT,
				'default'           => esc_html__('Sale', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_show_label' => 'yes'],
			]
		);

        //Custom Regular Price.
        $repeater->add_control(
			'bwdwpvx_regular_price', [
                'label'             => esc_html__('Regular Price', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::TEXT,
                'default'           => 12,
			]
		);

        //Custom Sale Price.
        $repeater->add_control(
			'bwdwpvx_sale_price', [
                'label'             => esc_html__('Sale Price', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::TEXT,
                'default'           => 8,
			]
		);

        //Show Button.
        $repeater->add_control(
            'bwdwpvx_show_btn', [
                'label'             => esc_html__('Show Button', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //Custom Button Text.
        $repeater ->add_control(
			'bwdwpvx_button', [
				'label'             => esc_html__('Button Text', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::TEXT,
				'dynamic'           => ['active' => true],
				'default'           => esc_html__('Order Now', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_show_btn' => 'yes'],
			]
		);

        //Button Link.
        $repeater->add_control(
			'bwdwpvx_link', [
				'label'              => esc_html__('Link', 'bwdwpvx-product-vendors'),
				'type'               => \Elementor\Controls_Manager::URL,
				'dynamic'            => [
					'active'         => true,
				],
				'placeholder'        => esc_html__('https://your-link.com', 'bwdwpvx-product-vendors'),
				'default'            => [
					'url'            => '#',
				],
                'condition'         => ['bwdwpvx_show_btn' => 'yes'],			
			]
		);

        //Show Customer Rating.
        $repeater->add_control(
            'bwdwpvx_show_customer_rating', [
                'label'             => esc_html__('Show Customer Rating', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //Custom Customer Rating.
        $repeater->add_control(
            'bwdwpvx_customer_rating', [
                'label'             => esc_html__('Customer Rating', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT,
                'options'           => [
                    '1'             => '1',
                    '2'             => '2',
                    '3'             => '3',
                    '4'             => '4',
                    '5'             => '5',
                ],
                'default'           => '3',
                'description'       => esc_html__('Select your rating.', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_show_customer_rating' => 'yes'],
            ]
        );

        //Show Highlight Product.
        $repeater->add_control(
            'bwdwpvx_show_highlight', [
                'label'             => esc_html__('Show Highlight Product', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'no',
            ]
        );

        //Custom Repeater Item Default.
        $this->add_control(
			'bwdwpvx_lists', [
				'label'             => esc_html__('List Item', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::REPEATER,
                'fields'            => $repeater->get_controls(),
                'default'           => [
                    [
                        'bwdwpvx_title'   => esc_html__('List One', 'bwdwpvx-product-vendors'),
                    ],
                    [
                        'bwdwpvx_title'   => esc_html__('List Two', 'bwdwpvx-product-vendors'),
                    ],
                    [
                        'bwdwpvx_title'   => esc_html__('List Three', 'bwdwpvx-product-vendors'),
                    ],
                ],
                'title_field'            => '{{{ bwdwpvx_title }}}'
			]
        );   

        $this->end_controls_section();
        //End Custom Item Section.

        //Start WooCommerce Item Section.
        $this->start_controls_section(
            'bwdwpvx_woo_item_section', array(
                'label'             => esc_html__('Item', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_product_source' => 'woocommerce'],
            )
        );

        //No. of Product.
        $this->add_control(
            'bwdwpvx_number_of_products', [
                'label'             => esc_html__('Display No. of Product', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::NUMBER,
				'min'               => 1,
				'max'               => 100,
				'step'              => 1,
				'default'           => 10,
            ]
        );

        //WooCommerce Show Image.
        $this->add_control(
            'bwdwpvx_show_image', [
                'label'             => esc_html__('Show Image', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
                'separator'         => 'before',
            ]
        );

        //WooCommerce Image Size.
        $this->add_group_control(
            \Elementor\Group_Control_Image_Size::get_type(), [
                'name'              => 'bwdwpvx_product_image_size',
                'exclude'           => ['custom'],
                'default'           => 'medium',
                'condition'         => ['bwdwpvx_show_image' => 'yes'],
            ]
        );

        //WooCommerce Show Title.
        $this->add_control(
            'bwdwpvx_show_title', [
                'label'             => esc_html__('Show Title', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'separator'         => 'before',
                'default'           => 'yes',
            ]
        );

        //WooCommerce Show Description.
        $this->add_control(
            'bwdwpvx_show_description', [
                'label'             => esc_html__('Show Description', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT,
                'options'           => [
                    'none'          => esc_html__('None', 'bwdwpvx-product-vendors'),
                    'short'         => esc_html__('Short', 'bwdwpvx-product-vendors'),
					'full'          => esc_html__('Full', 'bwdwpvx-product-vendors'),
                ],
                'default'           => 'short',
                'separator'         => 'after',
            ]
        );

        //WooCommerce Show Regular Price.
        $this->add_control(
            'bwdwpvx_show_regular_price', [
                'label'             => esc_html__('Show Regular Price', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //WooCommerce Show Sale Price.
        $this->add_control(
            'bwdwpvx_show_sale_price', [
                'label'             => esc_html__('Show Sale Price', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //WooCommerce Show Rating.
        $this->add_control(
            'bwdwpvx_show_rating', [
                'label'             => esc_html__('Show Rating', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //WooCommerce Sale Label Title.
        $this->add_control(
            'bwdwpvx_sale', [
                'label'             => esc_html__('Sale', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::HEADING,
                'separator'         => 'before',
            ]   
        );

        //WooCommerce Show Sale Label.
        $this->add_control(
            'bwdwpvx_show_label', [
                'label'             => esc_html__('Sale Label', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
                'separator'         => 'before',
            ]
        );

        //WooCommerce Sale Label Text.
        $this->add_control(
			'bwdwpvx_sale_label', [
				'label'             => esc_html__('Sale Label Text', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::TEXT,
				'default'           => esc_html__('Sale', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_show_label' => 'yes'],
			]
		);

        //WooCommerce Button Label.
        $this->add_control(
            'bwdwpvx_button', [
                'label'             => esc_html__('Button', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::HEADING,
                'separator'         => 'before',
            ]
        );

        //Show Cart Button.
        $this->add_control(
            'bwdwpvx_show_cart_button', [
                'label'             => esc_html__('Show Cart Button', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
                'separator'         => 'before',
            ]
        );

        //Show Custom Button.
        $this->add_control(
            'bwdwpvx_show_custom_button', [
                'label'             => esc_html__('Show Custom Button', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Show', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('Hide', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
                'condition'         => ['bwdwpvx_show_cart_button' => 'yes'],
            ]
        );

        //Simple Product Text.
        $this->add_control(
			'bwdwpvx_simple_button_text', [
				'label'             => esc_html__('Simple Product Text', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::TEXT,
				'default'           => esc_html__('Order Now', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_show_custom_button' => 'yes'],
			]   
		);

        //Grouped Product Text.
        $this->add_control(
			'bwdwpvx_grouped_button_text', [
				'label'             => esc_html__('Grouped Product Text', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::TEXT,
				'default'           => esc_html__('Order Now', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_show_custom_button' => 'yes'],
			]
		);

        //External/Affiliate Button Text.
        $this->add_control(
			'bwdwpvx_external_button_text', [
				'label'             => esc_html__('External/Affiliate Button Text', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::TEXT,
				'default'           => esc_html__('Order Now', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_show_custom_button' => 'yes'],
			]
		);

        //Variable Product Text.
        $this->add_control(
			'bwdwpvx_variable_button_text', [
				'label'             => esc_html__('Variable Product Text', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::TEXT,
				'default'           => esc_html__('Order Now', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_show_custom_button' => 'yes'],
			]
		);

        $this->end_controls_section();
        //End WooCommerce Item Section.

        //Start Products Query Section.
        $this->start_controls_section(
            'bwdwpvx_product_query_section', array(
                'label'             => esc_html__('Products Query', 'bwdwpvx-product-vendors'),
                'condition'         => ['bwdwpvx_product_source' => 'woocommerce'],
            )
        );

        //Product Source.
        $this->add_control(
            'apcw_product_source', [
                'label'         => esc_html__('Product Source', 'bwdwpvx-product-vendors'),
                'label_block'   => true,
                'type'          => \Elementor\Controls_Manager::SELECT,
                'default'       =>  'select',
                'multiple'      => true,
                'options'       => [
                    'select'                => esc_html__('Select', 'bwdwpvx-product-vendors' ),
					'recent-products'       => esc_html__('Recent Products', 'bwdwpvx-product-vendors' ),
					'featured-products'     => esc_html__('Featured Products', 'bwdwpvx-product-vendors' ),
                    'best-selling-products' => esc_html__('Best Selling Products', 'bwdwpvx-product-vendors' ),
                    'sale-products'         => esc_html__('Sale Products', 'bwdwpvx-product-vendors' ),
                    'top-products'          => esc_html__('Top Rated Products', 'bwdwpvx-product-vendors' ),
				],
            ]
        );

        //Include Categories.
        $this->add_control(
            'bwdwpvx_product_categories', [
                'label'             => esc_html__('Product Categories', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT2,
                'label_block'       => true,
                'multiple'          => true,
                'description'       => esc_html__('Select the categories you want to show', 'bwdwpvx-product-vendors'),
                'separator'         => 'before',
                'options'           => bwdwpvx_product_categories(),
            ]
        );

        //Exclude Categories.
        $this->add_control(
            'bwdwpvx_exclude_product_categories', [
                'label'             => esc_html__('Exclude Above Categories', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Yes', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('No', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //Include Tags.
        $this->add_control(
            'bwdwpvx_product_tags', [
                'label'             => esc_html__('Product Tags', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT2,
                'label_block'       => true,
                'multiple'          => true,
                'description'       => esc_html__('Select the tags you want to show', 'bwdwpvx-product-vendors'),
                'options'           => bwdwpvx_product_tags(),
                'separator'         => 'before',
            ]
        );

        //Exclude Tags.
        $this->add_control(
            'bwdwpvx_exclude_product_tags', [
                'label'             => esc_html__('Exclude Above Tags', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SWITCHER,
                'label_on'          => esc_html__('Yes', 'bwdwpvx-product-vendors'),
                'label_off'         => esc_html__('No', 'bwdwpvx-product-vendors'),
                'default'           => 'yes',
            ]
        );

        //Product Order By.
        $this->add_control(
            'bwdwpvx_product_orderby', [
                'label'             => esc_html__('Order By', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT,
                'default'           => 'date',
                'options'           => [
                'date'              => esc_html__('Date', 'bwdwpvx-product-vendors'),
                'title'             => esc_html__('Title', 'bwdwpvx-product-vendors'),
                'menu_order'        => esc_html__('Menu Order', 'bwdwpvx-product-vendors'),
                'rand'              => esc_html__('Random', 'bwdwpvx-product-vendors'),
                'ID'                => esc_html__('Post ID', 'bwdwpvx-product-vendors'),
                'author'            => esc_html__('Author', 'bwdwpvx-product-vendors'),
                'rating'            => esc_html__('Rating', 'bwdwpvx-product-vendors'),
                ],
            ]
        );

        //Product Sort By.
        $this->add_control(
            'bwdwpvx_product_sort_order', [
                'label'             => esc_html__('Sort By', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SELECT,
                'default'           => 'desc',
                'options'           => [
                    'asc'           => esc_html__('ASC', 'bwdwpvx-product-vendors'),
                    'desc'          => esc_html__('DESC', 'bwdwpvx-product-vendors'),
                ],
            ]
        );

        $this->end_controls_section();
        //End Products Query Section.
        //End Content Section

        //Style Section Start.
        //Start Item Style.
        $this->start_controls_section(
            'bwdwpvx_item_style', [
                'label'             => esc_html__('Item', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Item Background Color.
        $this->add_control( 
            'bwdwpvx_item_bg_color', [
                'label'             => esc_html__('Item Background Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-1 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-3 .bwdwpvx-content,
                    {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-content,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-content,
                    {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-content-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-content' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        //Item Highlight Background Color.
        $this->add_control( 
            'bwdwpvx_highlight_bg_color', [
                'label'             => esc_html__('Highlight Background Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-1 .bwdwpvx-item-container.bwdwpvx-highlight,
                    {{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-item-container.bwdwpvx-highlight,
                    {{WRAPPER}} .bwdwpvx-design-3 .bwdwpvx-item-container.bwdwpvx-highlight .bwdwpvx-content,
                    {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-item-container.bwdwpvx-highlight,
                    {{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-item-container.bwdwpvx-highlight,
                    {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-item-container.bwdwpvx-highlight .bwdwpvx-content,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-item-container.bwdwpvx-highlight .bwdwpvx-content,
                    {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-item-container.bwdwpvx-highlight,
                    {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-item-container.bwdwpvx-highlight .bwdwpvx-content-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container.bwdwpvx-highlight,
                    {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-item-container.bwdwpvx-highlight .bwdwpvx-content' => 'background-color: {{VALUE}} !important;',
                ],
                'condition'         => ['bwdwpvx_product_source' => 'custom'],
            ]
        );

        //Item Highlight Border Color.
        $this->add_control(
            'bwdwpvx_highlight_border_color', [
                'label'             => esc_html__('Highlight Border Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'default'           => '#ea1f2e',
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-highlight,
                    {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-item-container.bwdwpvx-highlight .bwdwpvx-content-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-item-container.bwdwpvx-highlight .bwdwpvx-content' => 'border-color: {{VALUE}} !important;',
                    '{{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-highlight.bwdwpvx-item-container::before' => 'background-color: {{VALUE}} !important;',
                ],
                'condition'         => ['bwdwpvx_product_source' => 'custom'],
            ]
        );

        //Item Divider Color.
        $this->add_control(
            'bwdwpvx_divider_color', [
                'label'             => esc_html__('Divider Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container::before' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container' => 'border-top-color: {{VALUE}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-10'],
                ]
            ]
        );

        //Item Divider Width.
        $this->add_control(
			'bwdwpvx_devider-width', [
                'label'             => esc_html__('Item Divider Width', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::SLIDER,
				'size_units'        => [ 'px' ],
				'range'             => [
					'px'            => [
						'min'       => 0,
						'max'       => 10,
						'step'      => 1,
					],
				],
				'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container::before' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container' => 'border-top-width: {{SIZE}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-10'],
                ]
			]
		);

        //Item Border.
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name'              => 'bwdwpvx_item_border',
                'selector'          => '{{WRAPPER}} .bwdwpvx-design-1 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-3 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-content-wrapper,
                {{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-content',
            ]
        );

        //Item Box Shadow.
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(), [
                'name'              => 'bwdwpvx_box_shadow',
                'selector'          => '{{WRAPPER}} .bwdwpvx-design-1 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-3 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-content-wrapper,
                {{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container,
                {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-content',
            ]
        );

        //Item Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_item_border_radius', [
                'label'             => esc_html__('Item Border Radius', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-1 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-3 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-content,
                    {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-content-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        //Item Padding.
        $this->add_responsive_control(
            'bwdwpvx_item_padding', [
                'label'             => esc_html__('Item Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-item-container,
                    {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-item-container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-5', 'bwdwpvx-design-8'],
                ]
            ]
        );

        //Item Content Padding.
        $this->add_responsive_control(
            'bwdwpvx_content_padding', [
                'label'             => esc_html__('Content Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2', 'bwdwpvx-design-3', 'bwdwpvx-design-4', 'bwdwpvx-design-5', 'bwdwpvx-design-6', 'bwdwpvx-design-7','bwdwpvx-design-8','bwdwpvx-design-10','bwdwpvx-design-11'],
                ]
            ]
        );

        //Item Content Padding.
        $this->add_responsive_control(
            'bwdwpvx_content_wrapper_padding', [
                'label'             => esc_html__('Content Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'default'           => [
                    'top'           => '20',
                    'right'         => '20',
                    'bottom'        => '20',
                    'left'          => '20',
                    'isLinked'      => true,
                ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-content-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-9'],
                ]
            ]
        );

        //Content Alignment.
        $this->add_responsive_control(
            'bwdwpvx_content_align', [
                'label'             => esc_html__('Alignment', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::CHOOSE,
                'options'           => [
                    'left'          => [
                        'title'     => esc_html__('Left', 'bwdwpvx-product-vendors'),
                        'icon'      => 'eicon-text-align-left',
                    ],
                    'center'        => [
                        'title'     => esc_html__('Center', 'bwdwpvx-product-vendors'),
                        'icon'      => 'eicon-text-align-center',
                    ],
                    'right'         => [
                        'title'     => esc_html__('Right', 'bwdwpvx-product-vendors'),
                        'icon'      => 'eicon-text-align-right',
                    ],
                ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-content' => 'text-align: {{VALUE}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-2', 'bwdwpvx-design-3', 'bwdwpvx-design-4', 'bwdwpvx-design-6', 'bwdwpvx-design-7','bwdwpvx-design-8', 'bwdwpvx-design-11'],
                ]
            ]
        );

        $this->end_controls_section();
        //End Item Style.

        //Start Category Style.
        $this->start_controls_section(
            'bwdwpvx_category_style', [
                'label'             => esc_html__('Category', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
                'condition'         => ['bwdwpvx_product_source' => 'woocommerce'],
            ]
        );

        //Category Typography.
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(), [
				'name'              => 'category_typography',
				'selector'          => '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-category',
			]
		);

        //Category Color.
        $this->add_control( 
            'bwdwpvx_category_color', [
                'label'             => esc_html__('Category Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-category' => 'color: {{VALUE}};',
                ],
            ]
        );

        //Category Background Color.
        $this->add_control( 
            'bwdwpvx_category_bg_color', [
                'label'             => esc_html__('Background Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-category' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        //Category Border.
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name'              => 'bwdwpvx_category_border',
                'selector'          => '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-category',
            ]
        );

        //Category Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_category_border_radius', [
                'label'             => esc_html__('Category Border Radius', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-category' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        //Category Padding.
        $this->add_responsive_control(
            'bwdwpvx_category_padding', [
                'label'             => esc_html__('Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-category' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        //Category Spacing.
        $this->add_responsive_control(
            'bwdwpvx_category_spacing', [
                'label'             => esc_html__('Category Spacing', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 100,
                    ],
                ],
                'frontend_available' => true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-category' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        //End Category Style.

        //Start Tag Style.
        $this->start_controls_section(
            'bwdwpvx_tag_style', [
                'label'             => esc_html__('Tag', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
                'condition'         => ['bwdwpvx_product_source' => 'woocommerce'],
            ]
        );

        //Tag Typography.
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(), [
				'name'              => 'bwdwpvx_tag_typography',
				'selector'          => '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-tag',
			]
		);

        //Tag Color.
        $this->add_control( 
            'bwdwpvx_tag_color', [
                'label'             => esc_html__('Tag Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-tag' => 'color: {{VALUE}};',
                ],
            ]
        );

        //Tag Background Color.
        $this->add_control( 
            'bwdwpvx_tag_bg_color', [
                'label'             => esc_html__('Background Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-tag' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        //Tag Border.
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name'              => 'bwdwpvx_tag_border',
                'selector'          => '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-tag',
            ]
        );

        //Tag Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_tag_border_radius', [
                'label'             => esc_html__('Tag Border Radius', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-tag' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        //Tag Padding.
        $this->add_responsive_control(
            'bwdwpvx_tag_padding', [
                'label'             => esc_html__('Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-tag' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        //Tag Spacing.
        $this->add_responsive_control(
            'bwdwpvx_tag_spacing', [
                'label'             => esc_html__('Tag Spacing', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 100,
                    ],
                ],
                'frontend_available' => true,
                'selectors'          => [
                    '{{WRAPPER}} .bwdwpvx-cat-tag-title .bwdwpvx-tag' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        //End Tag Style.

        //Start Image Style.
        $this->start_controls_section(
            'bwdwpvx_image_style', [
                'label'             => esc_html__('Image', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Image Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_image_border_radius', [
                'label'             => esc_html__('Image Border Radius', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-image img,
                    {{WRAPPER}} .bwdwpvx-woocommerce .bwdwpvx-img img,
                    {{WRAPPER}} .bwdwpvx-design-1 .bwdwpvx-img-icon-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-item-container:hover .bwdwpvx-image:after,
                    {{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-item-container:hover .bwdwpvx-layout-img:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2','bwdwpvx-design-4', 'bwdwpvx-design-5', 'bwdwpvx-design-7','bwdwpvx-design-9', 'bwdwpvx-design-11'],
                ]
            ]
        );

        //Image Border.
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name'              => 'bwdwpvx_image_border',
                'selector'          => '{{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-image img,
                {{WRAPPER}} .bwdwpvx-design-3 .bwdwpvx-image img,
                {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-image img,
                {{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-image img,
                {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-image img,
                {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-image img,
                {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-item-container .bwdwpvx-img-wrapper,
                {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-image img,
                {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-image img,
                {{WRAPPER}} .bwdwpvx-design-2 .bwdwpvx-layout-img img,
                {{WRAPPER}} .bwdwpvx-design-3 .bwdwpvx-layout-img img,
                {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-layout-img img,
                {{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-layout-img img,
                {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-layout-img img,
                {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-layout-img img,
                {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-layout-img,
                {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-layout-img img,
                {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-layout-img img',
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-2', 'bwdwpvx-design-3', 'bwdwpvx-design-4', 'bwdwpvx-design-5', 'bwdwpvx-design-6', 'bwdwpvx-design-7', 'bwdwpvx-design-8','bwdwpvx-design-9', 'bwdwpvx-design-10', 'bwdwpvx-design-11'],
                ]
            ]
        );

        //Image Padding.
        $this->add_responsive_control(
            'bwdwpvx_image_padding', [
                'label'             => esc_html__('Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-image,
                    {{WRAPPER}} .bwdwpvx-design-10 .bwdwpvx-img-icon-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-4','bwdwpvx-design-10'],
                ],
            ]   
        );

        //Image Width.
        $this->add_responsive_control(
            'bwdwpvx_image_width', [
                'label'             => esc_html__('Image Width', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'size_units'        => [ 'px', '%' ],
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 400,
                    ],
                    '%' => [
						'min' => 0,
						'max' => 100,
					],
                ],
                'frontend_available' => true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-layout-img .bwdwpvx-image img,
                    {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-image img,
                    {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-img-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-8 .bwdwpvx-woocommerce .bwdwpvx-layout-img,
                    {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-img-icon-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-layout-img'  => 'max-width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-img-icon-wrapper,
                    {{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-woocommerce .bwdwpvx-layout-img,
                    {{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-woocommerce .bwdwpvx-layout-img img,
                    {{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-img-icon-wrapper img,
                    {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-image img,
                    {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-woocommerce .bwdwpvx-img img,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-image img,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-woocommerce .bwdwpvx-img img'  => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2', 'bwdwpvx-design-4', 'bwdwpvx-design-5','bwdwpvx-design-7','bwdwpvx-design-8', 'bwdwpvx-design-9', 'bwdwpvx-design-10', 'bwdwpvx-design-11'],
                ]
            ]
        );

        //Image Width.
//         $this->add_responsive_control(
//             'bwdwpvx_image_height', [
//                 'label'             => esc_html__('Image Height', 'bwdwpvx-product-vendors'),
//                 'type'              => \Elementor\Controls_Manager::SLIDER,
//                 'size_units'        => [ 'px', '%' ],
//                 'range'             => [
//                     'px'            => [
//                         'min'       => 0,
//                         'max'       => 400,
//                     ],
//                     '%' => [
// 						'min' => 0,
// 						'max' => 100,
// 					],
//                 ],
//                 'frontend_available' => true,
//                 'selectors'         => [
//                     '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-img-wrapper,
//                     {{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-woocommerce .bwdwpvx-layout-img' => 'height: {{SIZE}}{{UNIT}};',
//                     '{{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-layout-img .bwdwpvx-image img,
//                     {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-image img'  => 'height: {{SIZE}}{{UNIT}};',
//                     '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-img-icon-wrapper,
//                     {{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-woocommerce .bwdwpvx-layout-img,
//                     {{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-woocommerce .bwdwpvx-layout-img .bwdwpvx-img img,
//                     {{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-img-icon-wrapper img,
//                     {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-image img,
//                     {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-woocommerce .bwdwpvx-img img,
//                     {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-image img,
//                     {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-woocommerce .bwdwpvx-img img'  => 'height: {{SIZE}}{{UNIT}};',
//                 ],
//                 'condition'         => [
//                     'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2', 'bwdwpvx-design-4', 'bwdwpvx-design-5','bwdwpvx-design-7','bwdwpvx-design-8', 'bwdwpvx-design-9', 'bwdwpvx-design-10', 'bwdwpvx-design-11'],
//                 ]
//             ]
//         );

		 $this->add_responsive_control(
            'bwdwpvx_image_height', [
                'label'             => esc_html__('Image Height', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'size_units'        => [ 'px', '%' ],
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 400,
                    ],
                    '%' => [
						'min' => 0,
						'max' => 100,
					],
                ],
                'frontend_available' => true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-img-wrapper,
                    {{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-woocommerce .bwdwpvx-layout-img' => 'height: {{SIZE}}{{UNIT}};',

                    '{{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-layout-img .bwdwpvx-image,
                    {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-image'  => 'height: {{SIZE}}{{UNIT}};',

                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-img-icon-wrapper,
                    {{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-woocommerce .bwdwpvx-layout-img,
                    {{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-woocommerce .bwdwpvx-layout-img .bwdwpvx-img,
                    {{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-img-icon-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-image,
                    {{WRAPPER}} .bwdwpvx-design-4 .bwdwpvx-woocommerce .bwdwpvx-img,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-image,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-woocommerce .bwdwpvx-img'  => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2', 'bwdwpvx-design-4', 'bwdwpvx-design-5','bwdwpvx-design-7','bwdwpvx-design-8', 'bwdwpvx-design-9', 'bwdwpvx-design-10', 'bwdwpvx-design-11'],
                ]
            ]
        );
		
        $this->end_controls_section();
        //End Box Style.

        //Start Title Style.
        $this->start_controls_section(
            'bwdwpvx_title_style', [
                'label'             => esc_html__('Title', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Title Typography.
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(), [
				'name'              => 'bwdwpvx_title_typography',
				'selector'          => '{{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-woocommerce .bwdwpvx-title a,
                {{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-title',
			]
		);

        //Title Color.
        $this->add_control( 
            'bwdwpvx_title_color', [
                'label'             => esc_html__('Title Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container.bwdwpvx-woocommerce .bwdwpvx-title a,
                {{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        //Title Spacing.
        $this->add_responsive_control(
            'bwdwpvx_title_spacing', [
                'label'             => esc_html__('Title Spacing', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 100,
                    ],
                ],
                'frontend_available' => true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-title-price-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-5 .bwdwpvx-title-wrapper,
                    {{WRAPPER}} .bwdwpvx-design-7 .bwdwpvx-title-wrapper' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2', 'bwdwpvx-design-3', 'bwdwpvx-design-4', 'bwdwpvx-design-6', 'bwdwpvx-design-7','bwdwpvx-design-8'],
                ]
            ]
        );

        //Title Spacing.
        $this->add_responsive_control(
            'bwdwpvx_title_odd_spacing', [
                'label'             => esc_html__('Title Spacing (odd)', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 200,
                    ],
                ],
                'default'   => [
					'unit'  => 'px',
					'size'  => 20,
				],
                'frontend_available' => true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-container .bwdwpvx-design-9:nth-child(odd) .bwdwpvx-title-wrapper ' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-9'],
                ]
            ]
        );

        //Title Spacing.
        $this->add_responsive_control(
            'bwdwpvx_title_even_spacing', [
                'label'             => esc_html__('Title Spacing (even)', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 200,
                    ],
                ],
                'frontend_available' => true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-container .bwdwpvx-design-9:nth-child(even) .bwdwpvx-title-wrapper ' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-9'],
                ]
            ]
        );

        //Dotted Separator Color.
        $this->add_control( 
            'bwdwpvx_separator_color', [
                'label'             => esc_html__('Dotted Separator Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-separator' => 'border-color: {{VALUE}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2', 'bwdwpvx-design-3', 'bwdwpvx-design-4', 'bwdwpvx-design-6', 'bwdwpvx-design-8' ],
                ]
            ]
        );

        $this->end_controls_section();
        //End Title Style.

        //Start Description Style.
        $this->start_controls_section(
            'bwdwpvx_description_style', [
                'label'             => esc_html__('Description', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Description Typography.
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(), [
				'name'              => 'bwdwpvx_description_typography',
				'selector'          => '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-description p',
			]
		);

        //Description Text Color.
        $this->add_control( 
            'bwdwpvx_description_color', [
                'label'             => esc_html__('Description Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-description p' => 'color: {{VALUE}};',
                ],
            ]
        );

//         //Description Spacing.
//         $this->add_responsive_control(
//             'bwdwpvx_description_spacing', [
//                 'label'             => esc_html__('Description Spacing', 'bwdwpvx-product-vendors'),
//                 'type'              => \Elementor\Controls_Manager::SLIDER,
//                 'range'             => [
//                     'px'            => [
//                         'min'       => 0,
//                         'max'       => 100,
//                     ],
//                 ],
//                 'frontend_available' => true,
//                 'selectors'          => [
//                     '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-description' => 'margin-top: {{SIZE}}{{UNIT}};',
//                 ],
//                 'condition'         => [
//                     'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2', 'bwdwpvx-design-3', 'bwdwpvx-design-4', 'bwdwpvx-design-6', 'bwdwpvx-design-7', 'bwdwpvx-design-8', 'bwdwpvx-design-9', 'bwdwpvx-design-10', 'bwdwpvx-design-11'],
//                 ]
//             ]
//         );

//         //Description Spacing.
//         $this->add_responsive_control(
//             'bwdwpvx_description_style_spacing', [
//                 'label'             => esc_html__('Description Spacing', 'bwdwpvx-product-vendors'),
//                 'type'              => \Elementor\Controls_Manager::SLIDER,
//                 'range'             => [
//                     'px'            => [
//                         'min'       => 0,
//                         'max'       => 100,
//                     ],
//                 ],
//                 'frontend_available' => true,
//                 'selectors'          => [
//                     '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-description p' => 'margin-left: {{SIZE}}{{UNIT}};',
//                 ],
//                 'condition'         => [
//                     'bwdwpvx_product_layout' => ['bwdwpvx-design-5' ],
//                 ]
//             ]
//         );

		 $this->add_control(
			'bwdwpvx_description_spacing_margin',
			[
				'label' => esc_html__( 'Margin', 'bwdwpvx-product-vendors' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
        $this->end_controls_section();
        //End Description Style.

        //Start Price Style.
        $this->start_controls_section(
            'bwdwpvx_price_style', [
                'label'             => esc_html__('Price', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Currency Symbol Position.
        $this->add_control(
			'bwdwpvx_currency_position', [
				'label'             => esc_html__('Currency Symbol Position', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::CHOOSE,
				'default'           => 'before',
				'options'           => [
					'before'        => [
						'title'     => esc_html__('Before', 'bwdwpvx-product-vendors'),
						'icon'      => 'eicon-h-align-left',
					],
					'after'         => [
						'title'     => esc_html__('After', 'bwdwpvx-product-vendors'),
						'icon'      => 'eicon-h-align-right',
					],
				],
                'condition'         => ['bwdwpvx_product_source' => 'custom'],
			]
		);

        //Regular Price Typography.
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(), [
				'name'              => 'bwdwpvx_regular_price_typography',
                'label'             => esc_html__('Regular Price Typography', 'bwdwpvx-product-vendors'),
				'selector'          => '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-regular-price',
			]
		);

        //Regular Price Color.
        $this->add_control( 
            'bwdwpvx_regular_color', [
                'label'             => esc_html__('Regular Price Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-regular-price' => 'color: {{VALUE}};',
                ],
            ]
        );

        // Price Color.
		$this->add_control(
			'bwdwpvx_price_line_color', [
				'label'         	=> esc_html__('Price Line Through', 'bwdwpvx-product-vendors'),
				'type'          	=> \Elementor\Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-line' => 'text-decoration-color: {{VALUE}};',
				],
			]
		);

		// Title Spacing.
		$this->add_responsive_control(
			'bwdwpvx_line_width', [
				'label' 			=> esc_html__('Price Line Through Width', 'bwdwpvx-product-vendors'),
				'type' 				=> \Elementor\Controls_Manager::SLIDER,
				'size_units' 		=> ['px'],
				'range'				=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 10,
						'step' 		=> 1,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 1,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-line' => 'text-decoration-thickness: {{SIZE}}{{UNIT}};',
				],
			]
		);

        //Sale Price Typography.
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(), [
				'name'              => 'bwdwpvx_sale_price_typography',
                'label'             => esc_html__('Sale Price Typography', 'bwdwpvx-product-vendors'),
				'selector'          => '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-sale-price',
			]
		);

        //Sale Price Color.
        $this->add_control( 
            'bwdwpvx_sale_color', [
                'label'             => esc_html__('Sale Price Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-sale-price' => 'color: {{VALUE}};',
                ],
            ]
        );

        //Price Background Color.
        $this->add_control( 
            'bwdwpvx_price_bg_color', [
                'label'             => esc_html__('Background Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'default'           => '#FFFFFF',
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-all-price' => 'background-color: {{VALUE}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-11'],
                ]
            ]
        );

        //Price Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_price_border_radius', [
                'label'             => esc_html__('Border Radius', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-all-price' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-11'],
                ]
            ]
        );

        //Price Padding.
        $this->add_responsive_control(
            'bwdwpvx_price_padding', [
                'label'             => esc_html__('Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-all-price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-11'],
                ]
            ]
        );

        //Price border.
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name'              => 'bwdwpvx_price_border',
                'selector'          => '{{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-all-price',
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-11'],
                ]
            ]
        );

        //Price Spacing.
        $this->add_responsive_control(
            'bwdwpvx_price_spacing', [
                'label'             => esc_html__('Price Spacing', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 100,
                    ],
                ],
                'default'           => [
					'unit'          => 'px',
					'size'          => 5,
				],
                'frontend_available' => true,
                'selectors'          => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-sale-price' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        //End Price Style.

        //Start Button Style.
        $this->start_controls_section(
            'bwdwpvx_button_style', [
                'label'             => esc_html__('Button', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Button Typography.
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name'              => 'bwdwpvx_button_typography',
                'selector'          => '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button-text',
            ]
        );

        //Button Spacing.
        $this->add_responsive_control(
            'bwdwpvx_button_spacing', [
                'label'             => esc_html__('Button Spacing', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 100,
                    ],
                ],
                'frontend_available' => true,
                'selectors'          => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        //Start Button Tab.
        $this->start_controls_tabs('bwdwpvx_button_color_tabs');

        //Start Normal Button Tab.
        $this->start_controls_tab('bwdwpvx_normal_button', [
            'label'                 => esc_html__('Normal', 'bwdwpvx-product-vendors'),
            ]
        );

        //Button Text Color.
        $this->add_control(
            'bwdwpvx_button_color', [
                'label'             => esc_html__('Text Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        //Button Background Color.
        $this->add_control(
            'bwdwpvx_button_bg_color', [
                'label'             => esc_html__('Button Background Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button .bwdwpvx-button-text' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        //End Normal Button Tab.

        //Start Hover Button Tab.
        $this->start_controls_tab('bwdwpvx_hover_button', [
            'label'                 => esc_html__('Hover', 'bwdwpvx-product-vendors'),
            ]
        );

        //Button Text Color.
        $this->add_control(
            'bwdwpvx_button_color_hover', [
                'label'             => esc_html__('Text Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button .bwdwpvx-button-text:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        //Button Background Color.
        $this->add_control(
            'bwdwpvx_button_bg_color_hover', [
                'label'             => esc_html__('Button Background Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button .bwdwpvx-button-text:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        //Button border.
        $this->add_control(
            'bwdwpvx_border_color_hover', [
                'label'             => esc_html__('Border Hover Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button .bwdwpvx-button-text:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        //End Hover Button Tab.

        $this->end_controls_tabs();
        //End Button Tab.

        //Button border.
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name'              => 'bwdwpvx_button_border',
                'selector'          => '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button .bwdwpvx-button-text',
            ]
        );

        //Button Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_border_radius', [
                'label'             => esc_html__('Border Radius', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button .bwdwpvx-button-text' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        //Button Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_button_padding', [
                'label'             => esc_html__('Button Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-button .bwdwpvx-button-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        //End Button Style.

        //Start Icon Style.
        $this->start_controls_section(
            'bwdwpvx_icon_style', [
                'label'             => esc_html__('Icon', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Icon Size.
        $this->add_responsive_control(
			'bwdwpvx_icon_size', [
				'label'             => esc_html__('Icon Size', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::SLIDER,
				'size_units'        => [ 'px', '%' ],
				'range'             => [
					'px'            => [
						'min'       => 0,
						'max'       => 100,
						'step'      => 1,
					],
				],
                'default'           => [
                    'size'          => 14,
					'unit'          => 'px',
                ],
				'selectors'         => [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-icon svg' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
				],
			]
		);

        //Icon Color.
        $this->add_control(
			'bwdwpvx_icon_color', [
				'label'             => esc_html__('Icon Color', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::COLOR,
                'default'           => '#ffffff',
				'selectors'         => [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-icon i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-icon svg' => 'fill:{{VALUE}}',
				],
			]
		);

        //Icon Background Color.
        $this->add_control(
			'bwdwpvx_icon_background_color', [
				'label'             => esc_html__('Icon Background Color', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::COLOR,
                'default'           => '#ea1f2e',
				'selectors'         => [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-icon' => 'background-color: {{VALUE}} !important;',
				],
			]
		);

        //Icon border.
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name'              => 'bwdwpvx_icon_border',
                'selector'          => '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-icon',
            ]
        );

        //Icon Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_icon_border_radius', [
                'label'             => esc_html__('Icon Border Radius', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        //Icon Padding.
        $this->add_responsive_control(
            'bwdwpvx_icon_padding', [
                'label'             => esc_html__('Icon Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        //End Icon Style.

        //Start Rating Style.
        $this->start_controls_section(
            'bwdwpvx_rating_style', [
                'label'             => esc_html__('Rating', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Rating Spacing.
        $this->add_responsive_control(
            'bwdwpvx_rating_spacing', [
                'label'             => esc_html__('Rating Spacing', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::SLIDER,
                'range'             => [
                    'px'            => [
                        'min'       => 0,
                        'max'       => 100,
                    ],
                ],
                'frontend_available' => true,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-rating,
                    {{WRAPPER}} .bwdwpvx-woocommerce .bwdwpvx-star-rating' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        //Rating Size.
        $this->add_control(
			'bwdwpvx_rating_size', [
				'label'             => esc_html__('Rating Size', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::SLIDER,
				'size_units'        => [ 'px', '%' ],
				'range'             => [
					'px'            => [
						'min'       => 0,
						'max'       => 100,
						'step'      => 1,
					],
				],
                'default'           => [
                    'size'          => 14,
					'unit'          => 'px',
                ],
				'selectors'         => [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-rating i,
                    {{WRAPPER}} .bwdwpvx-woocommerce .bwdwpvx-star-rating' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

        //Rating Color.
        $this->add_control(
			'bwdwpvx_rating_color', [
				'label'             => esc_html__('Rating Color', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::COLOR,
				'selectors'         => [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-rating .star,
                    {{WRAPPER}} .bwdwpvx-woocommerce .bwdwpvx-star-rating::before' => 'color: {{VALUE}};',
				],
			]
		);

        //Rating Fill Color.
        $this->add_control(
			'bwdwpvx_rating_fill_color', [
				'label'             => esc_html__('Rating Fill Color', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::COLOR,
				'selectors'         => [
					'{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-rating .star-fill,
                    {{WRAPPER}} .bwdwpvx-woocommerce .bwdwpvx-star-rating span' => 'color: {{VALUE}};',
				],
			]
		);

        $this->end_controls_section();
        //End Rating Style.

        //Start Label Style.
        $this->start_controls_section(
            'bwdwpvx_label_style', [
                'label'             => esc_html__('Label', 'bwdwpvx-product-vendors'),
                'tab'               => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Label Typography.
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name'              => 'bwdwpvx_label_typography',
                'selector'          => '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-label,
                {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-label',
            ]
        );

        //Label Color.
        $this->add_control( 
            'bwdwpvx_label_color', [
                'label'             => esc_html__('Label Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-label,
                    {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-label' => 'color: {{VALUE}};',
                ],
            ]
        );

        //Label Background Color.
        $this->add_control( 
            'bwdwpvx_label_bg_color', [
                'label'             => esc_html__('Label Background Color', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::COLOR,
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-label,
                    {{WRAPPER}} .bwdwpvx-design-3 .bwdwpvx-label::after,
                    {{WRAPPER}} .bwdwpvx-design-6 .bwdwpvx-label,
                    {{WRAPPER}} .bwdwpvx-design-11 .bwdwpvx-label::after' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        //Label Border.
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name'              => 'bwdwpvx_label_border',
                'selector'          => '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-label',
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-9'],
                ]
            ]
        );

        //Label Border Radius.
        $this->add_responsive_control(
            'bwdwpvx_label_border_radius', [
                'label'             => esc_html__('Label Border Radius', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-9'],
                ]
            ]
        );

        //Label Padding.
        $this->add_responsive_control(
            'bwdwpvx_label_padding', [
                'label'             => esc_html__('Label Padding', 'bwdwpvx-product-vendors'),
                'type'              => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'        => [ 'px', '%' ],
                'selectors'         => [
                    '{{WRAPPER}} .bwdwpvx-item-container .bwdwpvx-label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'         => [
                    'bwdwpvx_product_layout!' => 'bwdwpvx-design-6',
                    'bwdwpvx_product_layout' => ['bwdwpvx-design-1', 'bwdwpvx-design-2', 'bwdwpvx-design-4', 'bwdwpvx-design-5', 'bwdwpvx-design-7', 'bwdwpvx-design-8', 'bwdwpvx-design-9', 'bwdwpvx-design-10', 'bwdwpvx-design-11'],
                ]
            ]
        );

        //Rating Size.
        $this->add_responsive_control(
			'bwdwpvx_label_spacing', [
				'label'             => esc_html__('Label Spacing', 'bwdwpvx-product-vendors'),
				'type'              => \Elementor\Controls_Manager::SLIDER,
				'size_units'        => [ 'px', '%' ],
				'range'             => [
					'px'            => [
						'min'       => 0,
						'max'       => 100,
						'step'      => 1,
					],
				],
                'default'           => [
                    'size'          => 10,
					'unit'          => 'px',
                ],
				'selectors'         => [
					'{{WRAPPER}} .bwdwpvx-design-9 .bwdwpvx-label' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
                'condition'         => [
                    'bwdwpvx_product_layout' => 'bwdwpvx-design-9',
                ]
			]
		);

        $this->end_controls_section();
        //End Label Style.
        
        //End Style Section
    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        
        $args = array(
            'post_type'             => 'product',
            'posts_per_page'        => $settings['bwdwpvx_number_of_products'],
            'post_status'           => 'publish',
            'orderby'               => $settings['bwdwpvx_product_orderby'],
            'order'                 => $settings['bwdwpvx_product_sort_order'],
        );
        
        //Product per page.
        if (isset($settings['bwdwpvx_number_of_products']) && !empty($settings['bwdwpvx_number_of_products'])) {
            $args['posts_per_page'] = $settings['bwdwpvx_number_of_products'];
        } else {
            $args['posts_per_page'] = -1;
        }
        
        //Filter By Product Source.
        $args['meta_query'] = ['relation' => 'AND'];
        
        if ($settings['apcw_product_source'] == 'featured-products') {
            $args['tax_query'] = [
                'relation'  => 'AND',
                [
                    'taxonomy'  => 'product_visibility',
                    'field'     => 'name',
                    'terms'     => 'featured',
                ],
                [
                    'taxonomy'  => 'product_visibility',
                    'field'     => 'name',
                    'terms'     => ['exclude-from-search', 'exclude-from-catalog'],
                    'operator'  => 'NOT IN',
                ],
            ];
        } else if ($settings['apcw_product_source'] == 'best-selling-products') {
            $args['meta_key']   = 'total_sales';
            $args['orderby']    = 'meta_value_num';
            $args['order']      = 'DESC';
        } else if ($settings['apcw_product_source'] == 'sale-products') {
            $args['post__in']   = array_merge( array( 0 ), wc_get_product_ids_on_sale() );
        } else if ($settings['apcw_product_source'] == 'top-products') {
            $args['meta_key']   = '_wc_average_rating';
            $args['orderby']    = 'meta_value_num';
            $args['order']  = 'DESC';
        }
        
        //Exclude IN or NOT IN.
        if (isset($settings['bwdwpvx_exclude_product_categories']) && !empty($settings['bwdwpvx_exclude_product_categories'])) {
            $bwdwpvx_product_cats = 'NOT IN';
        } else {
            $bwdwpvx_product_cats = 'IN';
        }
        if (isset($settings['bwdwpvx_exclude_product_tags']) && !empty($settings['bwdwpvx_exclude_product_tags'])) {
            $bwdwpvx_product_tags = 'NOT IN';
        } else {
            $bwdwpvx_product_tags = 'IN';
        }
        
        //Query Check all Display Category and Tags.
        if ((isset($settings['bwdwpvx_product_categories']) && !empty($settings['bwdwpvx_product_categories'])) && (isset($settings['bwdwpvx_product_tags']) && !empty($settings['bwdwpvx_product_tags']))) {
            //Display All Product with Category and Tags //Condition AND.
            $args['tax_query'][] = array(
                'relation'       => 'AND',
                array(
                    'taxonomy'   => 'product_cat',
                    'field'      => 'ID',
                    'terms'      => $settings['bwdwpvx_product_categories'],
                    'operator'   => $bwdwpvx_product_cats,
                ),
                array(
                    'field'      => 'ID',
                    'taxonomy'   => 'product_tag',
                    'terms'      => $settings['bwdwpvx_product_tags'],
                    'operator'   => $bwdwpvx_product_tags,
                ),
            );
        } elseif (isset($settings['bwdwpvx_product_categories']) && !empty($settings['bwdwpvx_product_categories'])) {
            //Display All Product with Category.
            $args['tax_query'][] = array(
                array(
                    'taxonomy'   => 'product_cat',
                    'field'      => 'ID',
                    'terms'      => $settings['bwdwpvx_product_categories'],
                    'operator'   => $bwdwpvx_product_cats,
                ),
            );
        } elseif (isset($settings['bwdwpvx_product_tags']) && !empty($settings['bwdwpvx_product_tags'])) {
            //Display All Product with Tags. 
            $args['tax_query'][] = array(
                array(
                    'taxonomy'   => 'product_tag',
                    'field'      => 'ID',
                    'terms'      => $settings['bwdwpvx_product_tags'],
                    'operator'   => $bwdwpvx_product_tags,
                ),
            );
        }
        
        $products = new \WP_Query($args); ?>
        
        <div class="bwdwpvx-cat-tag-title">
            <?php
            //Product Category Title.
            if($settings['bwdwpvx_product_source'] == "woocommerce") {
                $bwdwpvx_term_ids = $settings['bwdwpvx_product_categories'];
                if (is_array($bwdwpvx_term_ids) || is_object($bwdwpvx_term_ids)){
                    foreach ($bwdwpvx_term_ids as $bwdwpvx_cat_id) {
                        $bwdwpvx_term = get_term_by('id', $bwdwpvx_cat_id, 'product_cat'); ?>
                        <h2 class="bwdwpvx-category">
                            <?php if ($bwdwpvx_term) {
                                echo $bwdwpvx_term->name;
                            } ?>
                        </h2>
                    <?php }
                }
                //Product Tag Title.
                $bwdwpvx_term_ids = $settings['bwdwpvx_product_tags'];
                if (is_array($bwdwpvx_term_ids) || is_object($bwdwpvx_term_ids)){
                    foreach ($bwdwpvx_term_ids as $bwdwpvx_tag_id) {
                        $bwdwpvx_term = get_term_by('id', $bwdwpvx_tag_id, 'product_tag'); ?>
                        <h2 class="bwdwpvx-tag">
                            <?php if ($bwdwpvx_term) {
                                echo $bwdwpvx_term->name;
                            } ?>
                        </h2>
                    <?php }
                } 
            }?>
        </div>
        <div class="bwdwpvx-container <?php echo $settings['bwdwpvx_product_layout'] ?>">
            <?php
            if($settings['bwdwpvx_product_source'] == "woocommerce" && class_exists('WooCommerce')) {
                //For Woocommerce Data.
                while ($products->have_posts()) : $products->the_post();  
                    switch ($settings['bwdwpvx_product_layout']) {
                        case 'bwdwpvx-design-1':
                            include __DIR__ . '/templates/designs/design-1.php'; // Design 1.
                            break;
                        case 'bwdwpvx-design-2':
                            include __DIR__ . '/templates/designs/design-2.php'; // Design 2.
                            break;
                        case 'bwdwpvx-design-3':
                            include __DIR__ . '/templates/designs/design-3.php'; // Design 3.
                            break;
                        case 'bwdwpvx-design-4':
                            include __DIR__ . '/templates/designs/design-4.php'; // Design 4.
                            break;
                        case 'bwdwpvx-design-5':
                            include __DIR__ . '/templates/designs/design-5.php'; // Design 5.
                            break;
                        case 'bwdwpvx-design-6':
                            include __DIR__ . '/templates/designs/design-6.php'; // Design 6.
                            break;
                        case 'bwdwpvx-design-7':
                            include __DIR__ . '/templates/designs/design-7.php'; // Design 7.
                            break;
                        case 'bwdwpvx-design-8':
                            include __DIR__ . '/templates/designs/design-8.php'; // Design 8.
                            break;
                        case 'bwdwpvx-design-9':
                            include __DIR__ . '/templates/designs/design-9.php'; // Design 9.
                            break;
                        case 'bwdwpvx-design-10':
                            include __DIR__ . '/templates/designs/design-10.php'; // Design 10.
                            break;
                        case 'bwdwpvx-design-11':
                            include __DIR__ . '/templates/designs/design-11.php'; // Design 11.
                            break;
                        default:
                            include __DIR__ . '/templates/designs/design-1.php'; // Default Design 1.
                            break;
                    }
                endwhile;
                wp_reset_postdata();
            }
            //For custom Data.
            if($settings['bwdwpvx_product_source'] == "custom") {
                switch ($settings['bwdwpvx_product_layout']) {
                    case 'bwdwpvx-design-1':
                        include( __DIR__ . '/templates/designs/design-1.php');
                        break;
                    case 'bwdwpvx-design-2':
                        include __DIR__ . '/templates/designs/design-2.php'; // Design 2.
                        break;
                    case 'bwdwpvx-design-3':
                        include __DIR__ . '/templates/designs/design-3.php'; // Design 3.
                        break;
                    case 'bwdwpvx-design-4':
                        include __DIR__ . '/templates/designs/design-4.php'; // Design 4.
                        break;
                    case 'bwdwpvx-design-5':
                        include __DIR__ . '/templates/designs/design-5.php'; // Design 5.
                        break;
                    case 'bwdwpvx-design-6':
                        include __DIR__ . '/templates/designs/design-6.php'; // Design 6.
                        break;
                    case 'bwdwpvx-design-7':
                        include __DIR__ . '/templates/designs/design-7.php'; // Design 7.
                        break;
                    case 'bwdwpvx-design-8':
                        include __DIR__ . '/templates/designs/design-8.php'; // Design 8.
                        break;
                    case 'bwdwpvx-design-9':
                        include __DIR__ . '/templates/designs/design-9.php'; // Design 9.
                        break;
                    case 'bwdwpvx-design-10':
                        include __DIR__ . '/templates/designs/design-10.php'; // Design 10.
                        break;
                    case 'bwdwpvx-design-11':
                        include __DIR__ . '/templates/designs/design-11.php'; // Design 11.
                        break;
                    default:
                        include __DIR__ . '/templates/designs/design-1.php'; // Default Design 1.
                        break;
                }
            } ?>
        </div>
        <?php
    }

}